View source: R/GroupSkewedGammaParameters.R
| calculate_stats_gamma | R Documentation |
This function computes the sample size, gamma distribution parameters (shape and rate), and Spearman correlation matrix for each group, based on the grouping column.
calculate_stats_gamma(data_df, group_col, using = c("MoM", "gMLE"))
data_df |
A data frame containing the data to be processed. |
group_col |
A character string specifying the name of the column to group by. |
using |
which method will be used to estimate the multivariate Gamma
shape and rate parameters. Defaults to |
A list of lists, where each inner list contains:
sample size (n)
sample mean vector (mean)
gamma distribution parameters (shape, rate)
Spearman correlation matrix (cor)
myData <- data.frame(
GENDER = c('Male', 'Female', 'Male', 'Female', 'Male', 'Female'),
VALUE1 = c(1.2, 2.3, 1.5, 2.7, 1.35, 2.5),
VALUE2 = c(3.4, 4.5, 3.8, 4.2, 3.6, 4.35)
)
calculate_stats_gamma(myData, "GENDER")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.